/* BdfServer - Copyright (c) 2012-2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.exportation.table;

import java.util.ArrayList;
import java.util.List;
import net.fichotheque.exportation.table.FormatColDef;
import net.fichotheque.exportation.table.TableDef;
import net.fichotheque.exportation.table.TableDefItem;
import net.fichotheque.format.FormatSourceKey;
import net.fichotheque.thesaurus.Thesaurus;
import net.fichotheque.thesaurus.metadata.ThesaurusFieldKey;
import net.fichotheque.thesaurus.metadata.ThesaurusLangChecker;
import net.fichotheque.tools.format.FichothequeFormatDefBuilder;
import net.fichotheque.utils.TableDefUtils;
import net.fichotheque.utils.ThesaurusUtils;
import net.mapeadores.util.format.FormatConstants;


/**
 *
 * @author Vincent Calame
 */
public class MotcleTableDefBuilder {

    private final List<TableDefItem> tableDefItemList = new ArrayList<TableDefItem>();

    private MotcleTableDefBuilder() {
    }

    public TableDef toTableDef() {
        return TableDefUtils.toTableDef(tableDefItemList);
    }

    private void addColDef(FormatColDef colDef) {
        tableDefItemList.add(colDef);
    }

    public static TableDef fromThesaurusMetadata(Thesaurus thesaurus, ThesaurusLangChecker thesaurusLangChecker) {
        MotcleTableDefBuilder builder = new MotcleTableDefBuilder();
        List<ThesaurusFieldKey> coreList = ThesaurusUtils.computeCoreFieldList(thesaurus, thesaurusLangChecker);
        for (ThesaurusFieldKey thesaurusFieldKey : coreList) {
            FichothequeFormatDefBuilder formatDefBuilder = new FichothequeFormatDefBuilder();
            formatDefBuilder.addSource(FormatSourceKey.newThesaurusFieldKeyInstance(thesaurusFieldKey));
            if (castToInteger(thesaurusFieldKey)) {
                formatDefBuilder.setCastType(FormatConstants.INTEGER_CAST);
            }
            FormatColDef colDef = TableDefUtils.toFormatColDef(thesaurusFieldKey.toString(), formatDefBuilder.toFichothequeFormatDef());
            builder.addColDef(colDef);
        }
        return builder.toTableDef();
    }

    private static boolean castToInteger(ThesaurusFieldKey thesaurusFieldKey) {
        if (thesaurusFieldKey.equals(ThesaurusFieldKey.ID)) {
            return true;
        }
        if (thesaurusFieldKey.equals(ThesaurusFieldKey.PARENT_ID)) {
            return true;
        }
        if (thesaurusFieldKey.equals(ThesaurusFieldKey.LEVEL)) {
            return true;
        }
        return false;
    }

}
